@@ -4,8 +4,10 @@ knitr::opts_chunk$set(
   comment = "#>"
 )
 
+in_pkgdown <- identical(Sys.getenv("IN_PKGDOWN"), "true")
+
 maybe_still <- function(url) {
-  if (pkgdown::in_pkgdown()) {
+  if (in_pkgdown) {
     url
   } else {
     gsub("\\.gif$", "-still.gif", url)
@@ -13,7 +15,7 @@ maybe_still <- function(url) {
 }
 
 ## ---- echo = FALSE, results = 'asis'------------------------------------------
-if (!pkgdown::in_pkgdown()) {
+if (!in_pkgdown) {
   cat(
     "Note: This vignette is best viewed [online](https://lintr.r-lib.org/articles/editors.html),",
     "where we can render full animations of editor flows.\n"
