@@ -1,15 +1,17 @@
 test_that("expect_null_linter skips allowed usages", {
+  linter <- expect_null_linter()
+
   # NB: this usage should be expect_false(), but this linter should
   #   nevertheless apply (e.g. for maintainers not using expect_not_linter)
-  expect_lint("expect_true(!is.null(x))", NULL, expect_null_linter())
+  expect_lint("expect_true(!is.null(x))", NULL, linter)
   # NB: also applies to tinytest, but it's sufficient to test testthat
-  expect_lint("testthat::expect_true(!is.null(x))", NULL, expect_null_linter())
+  expect_lint("testthat::expect_true(!is.null(x))", NULL, linter)
 
   # length-0 could be NULL, but could be integer() or list(), so let it pass
-  expect_lint("expect_length(x, 0L)", NULL, expect_null_linter())
+  expect_lint("expect_length(x, 0L)", NULL, linter)
 
   # no false positive for is.null() at the wrong positional argument
-  expect_lint("expect_true(x, is.null(y))", NULL, expect_null_linter())
+  expect_lint("expect_true(x, is.null(y))", NULL, linter)
 })
 
 test_that("expect_null_linter blocks simple disallowed usages", {
